# ninstd
A wrapper of Python using only standard libraries. <br>
This module is designed to be my base requirement of my further modules. <br>

## To install
```
pip install ninstd
```

## License
MIT License with some exceptions. <br>
Please look at comments within the module.


## TODO
- All.
